@@ -4,7 +4,7 @@
 ##   Notice: Copyright (c) 2002 Allen Day
 ##  Purpose: Attempt to determine video file type.  Based on /usr/share/magic
 ## Comments: None
-##      CVS: $Header: /cvsroot/Video-Info/Info/Magic.pm,v 1.15 2002/03/06 22:39:41 allenday Exp $
+##      CVS: $Header: /cvsroot/perlvideo/Info/Magic.pm,v 1.1 2002/10/17 11:49:17 allenday Exp $
 ##------------------------------------------------------------------------
 
 package Video::Info::Magic;
@@ -20,11 +20,11 @@ our $VERSION = '1.01';
 #we're going to use a enhexable string as the constant value
 #that matches the first four bytes of that filetype.  For lack
 #of better values.
-use constant VIDEO_UNKNOWN_FORMAT     => 0x00000001;
-use constant VIDEO_MPEG1              => 0x00000002;
-use constant VIDEO_MPEG2              => 0x00000003;
-use constant VIDEO_MPEG_LAYER_2       => 0x00000004;
-use constant VIDEO_MPEG_LAYER_3       => 0x00000005;
+use constant VIDEO_UNKNOWN_FORMAT     => 0x01;
+use constant VIDEO_MPEG1              => 0x02;
+use constant VIDEO_MPEG2              => 0x03;
+use constant VIDEO_MPEG_LAYER_2       => 0x04;
+use constant VIDEO_MPEG_LAYER_3       => 0x05;
 use constant VIDEO_MPEG_VIDEO_STREAM  => 0x000001b3;
 use constant VIDEO_MPEG_SYSTEM_STREAM => 0x000001ba;
 use constant VIDEO_RIFF               => 0x52494646;
@@ -33,11 +33,6 @@ use constant VIDEO_REALMEDIA          => 0x2e524d46;
 use constant VIDEO_QUICKTIME_MOOV     => 0x6d6f6f76;
 use constant VIDEO_QUICKTIME_MDAT     => 0x6d646174;
 use constant VIDEO_ASF1               => 0x75b22630;
-use constant VIDEO_DV_PAL             => 0x1f0700bf;
-use constant VIDEO_DV_NTSC            => 0x1f07003f;
-use constant AUDIO_WAV                => 0x00000016;
-use constant VIDEO_CDXA               => 0x00000016;
-use constant VIDEO_VDR                => 0x00000021;
 
 ##------------------------------------------------------------------------
 ## Items to export into callers namespace by default. Note: do not export
@@ -79,67 +74,44 @@ sub divine {
     my $filename = shift || die "divine(): please provide path/to/file";
     
     open(F,$filename) || die "divine(): couldn't open $filename: $!";
-    my($four1,$four2,$four3) = (undef,undef,undef);
-    sysread(F,$four1,4) == 4 or die "divine(): sysread() 1\n";
-    sysread(F,$four2,4) == 4 or die "divine(): sysread() 2\n";
-    sysread(F,$four3,4) == 4 or die "divine(): sysread() 3\n";
+    my $four = undef;
+    sysread(F,$four,4) == 4 or die "divine(): sysread()\n";
     close(F);
 
     ## convert the four bytes to an unsigned long
-    my $two = unpack( 'n', substr($four1,0,2) );
-    $four1    = unpack( 'N', $four1 );
-    $four2    = unpack( 'N', $four2 );
-    $four3    = unpack( 'N', $four3 );
-#warn $four1;
+    my $two = unpack( 'n', substr($four,0,2) );
+    $four    = unpack( 'N', $four );
+    # warn( sprintf( "Hex: 0x%04x\n", $two ) );
+    # warn( sprintf( "Hex: 0x%08x\n", $four ) );
 
 #TODO: MPEG1 MPEG2
     
     ## try to match the big, specific ones first
     my %table4 = (
-		  0x1f0700bf    =>  [VIDEO_DV_PAL,                'DV::PAL'], #doesn't exist
-		  0x1f07003f    =>  [VIDEO_DV_NTSC,              'DV::NTSC'], #doesn't exist
-		  0x000001b3    =>  [VIDEO_MPEG_VIDEO_STREAM,  'MPEG::LibMPEG3'],
-		  0x000001e0    =>  [VIDEO_MPEG_VIDEO_STREAM,  'MPEG::LibMPEG3'],
-		  0x00000300    =>  [VIDEO_MPEG_VIDEO_STREAM,  'MPEG::LibMPEG3'],
-		  0x000001ba    =>  [VIDEO_MPEG_SYSTEM_STREAM, 'MPEG::LibMPEG3'],
-		  0x52494646    =>  [VIDEO_RIFF,               'RIFF::Info'],
-		  0x41564920    =>  [VIDEO_RIFF,               'RIFF::Info'],
-		  0x2e7261fd    =>  [VIDEO_REALAUDIO,          'Real::Info'], #doesn't exist
-		  0x2e524d46    =>  [VIDEO_REALMEDIA,          'Real::Info'], #doesn't exist
-		  0x6d6f6f76    =>  [VIDEO_QUICKTIME_MOOV,'QuickTime::Info'],
-		  0x6d646174    =>  [VIDEO_QUICKTIME_MDAT,'QuickTime::Info'],
-		  0x3026b275    =>  [VIDEO_ASF1,                'ASF::Info'],
-        	  0x00000021    =>  [VIDEO_VDR,                'MPEG::LibMPEG3'], #dunno about this one
-        	  #these are for subtyping RIFF files
-		  0x57415645    =>  [AUDIO_WAV,                'Audio::Wav'],
-        	  0x43445841    =>  [VIDEO_CDXA,               'RIFF::Info'], #MPEG after RIFF header... weird
+		  0x000001b3    =>  [VIDEO_MPEG_VIDEO_STREAM,  'MPEG'],
+		  0x000001ba    =>  [VIDEO_MPEG_SYSTEM_STREAM, 'MPEG'],
+		  0x52494646    =>  [VIDEO_RIFF,               'RIFF'],
+		  0x41564920    =>  [VIDEO_RIFF,               'RIFF'],
+		  0x2e7261fd    =>  [VIDEO_REALAUDIO,          'Real'],
+		  0x2e524d46    =>  [VIDEO_REALMEDIA,          'Real'],
+		  0x6d6f6f76    =>  [VIDEO_QUICKTIME_MOOV,'QuickTime'],
+		  0x6d646174    =>  [VIDEO_QUICKTIME_MDAT,'QuickTime'],
+		  0x3026b275    =>  [VIDEO_ASF1,                'ASF'],
 		  );
-
-#		  0x75b22630    =>  [VIDEO_ASF1,                'ASF::Info'],
+#		  0x75b22630    =>  [VIDEO_ASF1,                'ASF'],
     
     ## there may be more possible second bits (f0-f9) for MPEG I audio layers
     my %table2 = (
-		  0x4944       =>  [VIDEO_MPEG_LAYER_3,        'MP3::Info'], #THIS HAS AN ID3 TAG
-		  0xfffa       =>  [VIDEO_MPEG_LAYER_3,        'MP3::Info'], #11111010 MP3
-		  0xfffb       =>  [VIDEO_MPEG_LAYER_3,        'MP3::Info'], #11111011 MP3
-		  0xfffc       =>  [VIDEO_MPEG_LAYER_2,        'MP3::Info'], #11111100 MP2_FC
-		  0xfffd       =>  [VIDEO_MPEG_LAYER_2,        'MP3::Info'], #11111101 MP2
-		  0xfffe       =>  [VIDEO_MPEG_LAYER_3,        'MP3::Info'], #11111110 probably
-		  0xffff       =>  [VIDEO_MPEG_LAYER_3,        'MP3::Info'], #11111111 not yet
+		  0xfffa       =>  [VIDEO_MPEG_LAYER_3,        'MP3'], #11111010 for sure
+		  0xfffb       =>  [VIDEO_MPEG_LAYER_3,        'MP3'], #11111011 for sure
+		  0xfffc       =>  [VIDEO_MPEG_LAYER_2,        'MP3'], #11111100 for sure
+		  0xfffd       =>  [VIDEO_MPEG_LAYER_2,        'MP3'], #11111101 not yet
+		  0xfffe       =>  [VIDEO_MPEG_LAYER_3,        'MP3'], #11111110 probably
+		  0xffff       =>  [VIDEO_MPEG_LAYER_3,        'MP3'], #11111111 not yet
+		  0x4944       =>  [VIDEO_MPEG_LAYER_3,        'MP3'], #THIS HAS AN ID3 TAG
 		  );
-
-#warn "2\t".$table4{$four1};
-	if($table4{$four1} == VIDEO_RIFF){
-		#try to catch RIFF subtypes
-		$table4{$four3} ? return $table4{$four3} : 0;
-
-		#or default to RIFF
-		return $table4{$four1};
-	}
-	elsif($table4{$four1}){
-		return $table4{$four1};
-	}
-
+    
+    $table4{$four} ? return $table4{$four} : 0;
     $table2{$two}  ? return $table2{$two} : 0;
     
     return [VIDEO_UNKNOWN_FORMAT,undef];
@@ -172,8 +144,8 @@ sub acodec2str {
 	       0x111      => 'Vivo G.723',
 	       0x112      => 'Vivo G.723/Siren',
 	       0x130      => 'ACELP.net Sipro Lab Audio Decoder',
-	       0x160      => 'DivX audio (WMA1)',
-	       0x161      => 'DivX audio (WMA2)',
+	       0x160      => 'DivX audio (WMA)',
+	       0x161      => 'DivX audio (WMA)',
 	       0x270      => 'Sony ATRAC3',
 	       0x401      => 'Intel Music Coder',
 	       0x2000     => 'AC3',
@@ -224,7 +196,9 @@ as well as GUID and other info from Microsoft, mplayer, transcode...
 
 =head1 AUTHOR
 
-Allen Day <allenday@ucla.edu>
+ Copyright (c) 2002
+ Aladdin Free Public License (see LICENSE for details)
+ Allen Day <allenday@ucla.edu>
 
 =head1 SEE ALSO
 
